OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "U zdravlje!",
    "Location:" : "Lokacija:",
    "Today" : "Today",
    "Preview" : "Pregled",
    "Copy link" : "Kopiraj vezu",
    "Edit" : "Izmeni",
    "Delete" : "Delete",
    "Empty trash bin" : "Isprazni kantu",
    "Name" : "Ime",
    "Deleted" : "Obrisano",
    "Delete permanently" : "Obriši zauvek",
    "Copy internal link" : "Kopiraj internu vezu",
    "Share link" : "Veza deljenja",
    "Save" : "Save",
    "Filename" : "Ime fajla",
    "Cancel" : "Cancel",
    "List view" : "Prikaz liste",
    "Appearance" : "Izgled",
    "Files" : "Fajlovi",
    "Update" : "Ažuriraj",
    "Description" : "Opis",
    "Add" : "Dodaj",
    "Monday" : "Ponedeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Sreda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sunday" : "Nedelja",
    "Email" : "email",
    "Proceed" : "Nastavi",
    "Out of office" : "Van kancelarije",
    "Done" : "Gotovo",
    "Unknown" : "Nepoznato",
    "never" : "never",
    "Yes" : "Da",
    "No" : "Ne",
    "None" : "Ništa",
    "Close" : "Zatvori",
    "Participants" : "Učesnici",
    "Daily" : "дневно",
    "Weekly" : "недељно",
    "second" : "sekund",
    "Other" : "Ostali",
    "can edit" : "može da menja"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
